###########
User Guide
###########

In this user guide, you will find detailed descriptions and examples that describe the many capabilities of Swiftest and how to use them.

- Setting up a :doc:`Basic Simulation <basic-simulation>`

- A more in-depth :doc:`Detailed Simulation Setup <detailed-simulation-setup>`

- Setting up :doc:`Planetocentric Initial Conditions <planetocentric-init_cond>`

- Using the :doc:`Standalone Executable <standalone-executable>`

- Understanding the :doc:`Gravitational Harmonics capabilities <gravitational-harmonics>`

.. toctree::
   :maxdepth: 2
   :hidden:

   Basic simulation <basic-simulation>
   Detailed simulation setup <detailed-simulation-setup>
   Planetocentric Initial Conditions <planetocentric-init_cond>
   Using the standalone executable <standalone-executable>
   Using SHTOOLS to model non-spherical central bodies <gravitational-harmonics>